# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.1.0-1-ga85a9c1
https://git.km3net.de/common/km3net-dataformat
"""

# trigger
data = dict(
    JTRIGGER3DSHOWER=1,
    JTRIGGERMXSHOWER=2,
    JTRIGGER3DMUON=4,
    JTRIGGERNB=5,
    FACTORY_LIMIT=31,
)



from pkg_resources import get_distribution, DistributionNotFound

version = get_distribution(__name__).version

import warnings

with warnings.catch_warnings():
    for warning_category in (FutureWarning, DeprecationWarning):
        warnings.simplefilter("ignore", category=warning_category)
    import uproot3

from .offline import OfflineReader
from .online import OnlineReader
from .acoustics import RawAcousticReader
from .gseagen import GSGReader
